[CalendarServer-changes] [10652] CalendarServer/branches/release/CalendarServer-4.3-dev/ calendarserver/tools/purge.py

source_changes at macosforge.org source_changes at macosforge.org
Wed Feb 6 11:44:00 PST 2013


Revision: 10652
          http://trac.calendarserver.org//changeset/10652
Author:   sagen at apple.com
Date:     2013-02-06 11:44:00 -0800 (Wed, 06 Feb 2013)
Log Message:
-----------
Purge tool removes the free-busy indexing limit

Modified Paths:
--------------
    CalendarServer/branches/release/CalendarServer-4.3-dev/calendarserver/tools/purge.py

Modified: CalendarServer/branches/release/CalendarServer-4.3-dev/calendarserver/tools/purge.py
===================================================================
--- CalendarServer/branches/release/CalendarServer-4.3-dev/calendarserver/tools/purge.py	2013-02-06 19:04:03 UTC (rev 10651)
+++ CalendarServer/branches/release/CalendarServer-4.3-dev/calendarserver/tools/purge.py	2013-02-06 19:44:00 UTC (rev 10652)
@@ -85,9 +85,10 @@
 
     def doWork(self):
         """
         Turn off attendee refresh batching
         """
         config.Scheduling.Options.AttendeeRefreshBatch = 0
+        config.FreeBusyIndexLowerLimitDays = 0
         return succeed(None)
 
 
-------------- next part --------------
@@ -85,9 +85,10 @@
     def doWork(self):
         """
-        Turn off attendee refresh batching
+        Turn off attendee refresh batching and remove the free/busy index limit 
         """
         config.Scheduling.Options.AttendeeRefreshBatch = 0
An HTML attachment was scrubbed...
URL: <http://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20130206/76c998ad/attachment.html>


More information about the calendarserver-changes mailing list